#[repr(C)]pub struct burn_progress {Show 13 fields
pub sessions: c_int,
pub session: c_int,
pub tracks: c_int,
pub track: c_int,
pub indices: c_int,
pub index: c_int,
pub start_sector: c_int,
pub sectors: c_int,
pub sector: c_int,
pub buffer_capacity: c_uint,
pub buffer_available: c_uint,
pub buffered_bytes: off_t,
pub buffer_min_fill: c_uint,
}Expand description
Operation progress report. All values are 0 based indices.
Fields
sessions: c_intThe total number of sessions
session: c_intCurrent session.
tracks: c_intThe total number of tracks
track: c_intCurrent track.
indices: c_intThe total number of indices
index: c_intCurrent index.
start_sector: c_intThe starting logical block address
sectors: c_intOn write: The number of sectors. On blank: 0x10000 as upper limit for relative progress steps
sector: c_intOn write: The current sector being processed. On blank: Relative progress steps 0 to 0x10000
buffer_capacity: c_uintThe capacity of the drive buffer
buffer_available: c_uintThe free space in the drive buffer (might be slightly outdated)
buffered_bytes: off_tThe number of bytes sent to the drive buffer
buffer_min_fill: c_uintThe minimum number of bytes stored in buffer during write. (Caution: Before surely one buffer size of bytes was processed, this value is 0xffffffff.)