#[repr(C)]pub struct burn_toc_entry {Show 19 fields
pub session: c_uchar,
pub adr: c_uchar,
pub control: c_uchar,
pub tno: c_uchar,
pub point: c_uchar,
pub min: c_uchar,
pub sec: c_uchar,
pub frame: c_uchar,
pub zero: c_uchar,
pub pmin: c_uchar,
pub psec: c_uchar,
pub pframe: c_uchar,
pub extensions_valid: c_uchar,
pub session_msb: c_uchar,
pub point_msb: c_uchar,
pub start_lba: c_int,
pub track_blocks: c_int,
pub last_recorded_address: c_int,
pub track_status_bits: c_int,
}Expand description
Information about a track on a disc - this is from the q sub channel of the lead-in area of a disc. The documentation here is very terse. See a document such as mmc3 for proper information.
CAUTION : This structure is prone to future extension !
Do not restrict your application to unsigned char with any counter like "session", "point", "pmin", … Do not rely on the current size of a burn_toc_entry.
Fields
session: c_ucharSession the track is in
adr: c_ucharType of data. for this struct to be valid, it must be 1
control: c_ucharType of data in the track
tno: c_ucharZero. Always. Really.
point: c_ucharTrack number or special information
min: c_ucharsec: c_ucharframe: c_ucharzero: c_ucharpmin: c_ucharTrack start time minutes for normal tracks
psec: c_ucharTrack start time seconds for normal tracks
pframe: c_ucharTrack start time frames for normal tracks
extensions_valid: c_ucharsession_msb: c_ucharpoint_msb: c_ucharstart_lba: c_inttrack_blocks: c_intlast_recorded_address: c_inttrack_status_bits: c_intTrait Implementations
Sourceimpl Clone for burn_toc_entry
impl Clone for burn_toc_entry
Sourcefn clone(&self) -> burn_toc_entry
fn clone(&self) -> burn_toc_entry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for burn_toc_entry
impl Debug for burn_toc_entry
impl Copy for burn_toc_entry